@@ -8,7 +8,7 @@ from drf_yasg.views import get_schema_view
 view = get_schema_view(
     openapi.Info('bla', 'ble'),
     public=False,
-    permission_classes=[permissions.AllowAny]
+    permission_classes=(permissions.AllowAny,)
 )
 view = view.without_ui(cache_timeout=None)
 
